==> zio-aws-sagemakergeospatial_3-5.19.31.3-sources.jar: zio/aws/sagemakergeospatial/model/package.scala <==
package zio.aws.sagemakergeospatial
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.sagemakergeospatial.model.primitives.ListVectorEnrichmentJobInputMaxResultsInteger.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.sagemakergeospatial.model.primitives.Arn.Type
    object BinaryFile extends Subtype[Chunk[Byte]]
    type BinaryFile =
      zio.aws.sagemakergeospatial.model.primitives.BinaryFile.Type
    object DataCollectionArn extends Subtype[String]
    type DataCollectionArn =
      zio.aws.sagemakergeospatial.model.primitives.DataCollectionArn.Type
    object EarthObservationJobArn extends Subtype[String]
    type EarthObservationJobArn =
      zio.aws.sagemakergeospatial.model.primitives.EarthObservationJobArn.Type
    type Integer = Int
    object ListEarthObservationJobInputMaxResultsInteger extends Subtype[Int]
    type ListEarthObservationJobInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListEarthObservationJobInputMaxResultsInteger.Type
    object ListRasterDataCollectionsInputMaxResultsInteger extends Subtype[Int]
    type ListRasterDataCollectionsInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListRasterDataCollectionsInputMaxResultsInteger.Type
    object ListVectorEnrichmentJobInputMaxResultsInteger extends Subtype[Int]
    type ListVectorEnrichmentJobInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListVectorEnrichmentJobInputMaxResultsInteger.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.sagemakergeospatial.model.primitives.NextToken.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakergeospatial.model.primitives.Timestamp.Type
    object VectorEnrichmentJobArn extends Subtype[String]
    type VectorEnrichmentJobArn =
      zio.aws.sagemakergeospatial.model.primitives.VectorEnrichmentJobArn.Type
  }
  type AssetsMap = Map[String, zio.aws.sagemakergeospatial.model.AssetValue]
  type DataCollectionsList =
    List[zio.aws.sagemakergeospatial.model.RasterDataCollectionMetadata]
  type EarthObservationJobList =
    List[zio.aws.sagemakergeospatial.model.ListEarthObservationJobOutputConfig]
  type EarthObservationJobOutputBands =
    List[zio.aws.sagemakergeospatial.model.OutputBand]
  type FilterList = List[zio.aws.sagemakergeospatial.model.Filter]
  type ImageSourceBandList = List[String]
  type ItemSourceList = List[zio.aws.sagemakergeospatial.model.ItemSource]
  type LinearRing = List[Iterable[Double]]
  type LinearRings = List[Iterable[Iterable[Double]]]
  type LinearRingsList = List[Iterable[Iterable[Iterable[Double]]]]
  type OperationsListInput = List[zio.aws.sagemakergeospatial.model.Operation]
  type Position = List[Double]
  type PropertyFiltersList =
    List[zio.aws.sagemakergeospatial.model.PropertyFilter]
  type StringListInput = List[String]
  type TagKeyList = List[String]
  type Tags = Map[String, String]
  type TemporalStatisticsListInput =
    List[zio.aws.sagemakergeospatial.model.TemporalStatistics]
  type VectorEnrichmentJobList =
    List[zio.aws.sagemakergeospatial.model.ListVectorEnrichmentJobOutputConfig]
  type ZonalStatisticsListInput =
    List[zio.aws.sagemakergeospatial.model.ZonalStatistics]
}

==> zio-aws-sagemakergeospatial_3-6.20.74.2-sources.jar: zio/aws/sagemakergeospatial/model/package.scala <==
package zio.aws.sagemakergeospatial
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.sagemakergeospatial.model.primitives.StartEarthObservationJobInputNameString.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.sagemakergeospatial.model.primitives.Arn.Type
    object BinaryFile extends Subtype[Chunk[Byte]]
    type BinaryFile =
      zio.aws.sagemakergeospatial.model.primitives.BinaryFile.Type
    object DataCollectionArn extends Subtype[String]
    type DataCollectionArn =
      zio.aws.sagemakergeospatial.model.primitives.DataCollectionArn.Type
    object EarthObservationJobArn extends Subtype[String]
    type EarthObservationJobArn =
      zio.aws.sagemakergeospatial.model.primitives.EarthObservationJobArn.Type
    object ExecutionRoleArn extends Subtype[String]
    type ExecutionRoleArn =
      zio.aws.sagemakergeospatial.model.primitives.ExecutionRoleArn.Type
    object ExportEarthObservationJobInputClientTokenString
        extends Subtype[String]
    type ExportEarthObservationJobInputClientTokenString =
      zio.aws.sagemakergeospatial.model.primitives.ExportEarthObservationJobInputClientTokenString.Type
    object ExportVectorEnrichmentJobInputClientTokenString
        extends Subtype[String]
    type ExportVectorEnrichmentJobInputClientTokenString =
      zio.aws.sagemakergeospatial.model.primitives.ExportVectorEnrichmentJobInputClientTokenString.Type
    type Integer = Int
    object KmsKey extends Subtype[String]
    type KmsKey = zio.aws.sagemakergeospatial.model.primitives.KmsKey.Type
    object ListEarthObservationJobInputMaxResultsInteger extends Subtype[Int]
    type ListEarthObservationJobInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListEarthObservationJobInputMaxResultsInteger.Type
    object ListRasterDataCollectionsInputMaxResultsInteger extends Subtype[Int]
    type ListRasterDataCollectionsInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListRasterDataCollectionsInputMaxResultsInteger.Type
    object ListVectorEnrichmentJobInputMaxResultsInteger extends Subtype[Int]
    type ListVectorEnrichmentJobInputMaxResultsInteger =
      zio.aws.sagemakergeospatial.model.primitives.ListVectorEnrichmentJobInputMaxResultsInteger.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.sagemakergeospatial.model.primitives.NextToken.Type
    object S3Uri extends Subtype[String]
    type S3Uri = zio.aws.sagemakergeospatial.model.primitives.S3Uri.Type
    object StartEarthObservationJobInputClientTokenString
        extends Subtype[String]
    type StartEarthObservationJobInputClientTokenString =
      zio.aws.sagemakergeospatial.model.primitives.StartEarthObservationJobInputClientTokenString.Type
    object StartEarthObservationJobInputNameString extends Subtype[String]
    type StartEarthObservationJobInputNameString =
      zio.aws.sagemakergeospatial.model.primitives.StartEarthObservationJobInputNameString.Type
    object StartVectorEnrichmentJobInputClientTokenString
        extends Subtype[String]
    type StartVectorEnrichmentJobInputClientTokenString =
      zio.aws.sagemakergeospatial.model.primitives.StartVectorEnrichmentJobInputClientTokenString.Type
    object StartVectorEnrichmentJobInputNameString extends Subtype[String]
    type StartVectorEnrichmentJobInputNameString =
      zio.aws.sagemakergeospatial.model.primitives.StartVectorEnrichmentJobInputNameString.Type
    object SyntheticTimestamp_date_time extends Subtype[Instant]
    type SyntheticTimestamp_date_time =
      zio.aws.sagemakergeospatial.model.primitives.SyntheticTimestamp_date_time.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.sagemakergeospatial.model.primitives.Timestamp.Type
    object VectorEnrichmentJobArn extends Subtype[String]
    type VectorEnrichmentJobArn =
      zio.aws.sagemakergeospatial.model.primitives.VectorEnrichmentJobArn.Type
  }
  type AssetsMap = Map[String, zio.aws.sagemakergeospatial.model.AssetValue]
  type DataCollectionsList =
    List[zio.aws.sagemakergeospatial.model.RasterDataCollectionMetadata]
  type EarthObservationJobList =
    List[zio.aws.sagemakergeospatial.model.ListEarthObservationJobOutputConfig]
  type EarthObservationJobOutputBands =
    List[zio.aws.sagemakergeospatial.model.OutputBand]
  type FilterList = List[zio.aws.sagemakergeospatial.model.Filter]
  type ImageSourceBandList = List[String]
  type ItemSourceList = List[zio.aws.sagemakergeospatial.model.ItemSource]
  type LinearRing = List[Iterable[Double]]
  type LinearRings = List[Iterable[Iterable[Double]]]
  type LinearRingsList = List[Iterable[Iterable[Iterable[Double]]]]
  type OperationsListInput = List[zio.aws.sagemakergeospatial.model.Operation]
  type Position = List[Double]
  type PropertyFiltersList =
    List[zio.aws.sagemakergeospatial.model.PropertyFilter]
  type StringListInput = List[String]
  type TagKeyList = List[String]
  type Tags = Map[String, String]
  type TemporalStatisticsListInput =
    List[zio.aws.sagemakergeospatial.model.TemporalStatistics]
  type VectorEnrichmentJobList =
    List[zio.aws.sagemakergeospatial.model.ListVectorEnrichmentJobOutputConfig]
  type ZonalStatisticsListInput =
    List[zio.aws.sagemakergeospatial.model.ZonalStatistics]
}
